@@ -3,7 +3,23 @@ package MojoMojo::Schema::Result::Link;
 use strict;
 use warnings;
 
-use parent qw/MojoMojo::Schema::Base::Result/;
+use parent 'MojoMojo::Schema::Base::Result';
+
+=head1 NAME
+
+MojoMojo::Schema::Result::Link - Links among pages
+
+=head1 ATTRIBUTES
+
+=head2 from_page
+
+L<MojoMojo::Schema::Result::Page> object being the source of a link
+
+=head2 to_page
+
+L<MojoMojo::Schema::Result::Page> object being the target of a link
+
+=cut
 
 __PACKAGE__->load_components( "Core" );
 __PACKAGE__->table("link");
@@ -19,10 +35,6 @@ __PACKAGE__->set_primary_key("id");
 __PACKAGE__->belongs_to( "from_page", "MojoMojo::Schema::Result::Page", { id => "from_page" } );
 __PACKAGE__->belongs_to( "to_page",   "MojoMojo::Schema::Result::Page", { id => "to_page" } );
 
-=head1 NAME
-
-MojoMojo::Schema::Result::Link
-
 =head1 AUTHOR
 
 Marcus Ramberg <mramberg@cpan.org>
