@@ -206,17 +206,17 @@ $( function() {
         return false;
     });
    $('.image img').hover(function() {
-        var info_url=$(this).parent().attr('href').replace(/.photo\//,'.jsrpc/imginfo/');
+        var info_url=$(this).parent().attr('href').replace(/.photo.*\//,'.jsrpc/imginfo/');
         $('#imageinfo').load(info_url)
     },function() {})
 
     $('#do_upload').each(function() {
         uploader=new SWFUpload({
             button_placeholder_id: "do_upload",
-            button_image_url: $.uri_for("/.static/gfx/uploadbutton.png"),
+            button_image_url: $.uri_for_static("/gfx/uploadbutton.png"),
             button_width: 61,
             button_height: 22,
-            flash_url: $.uri_for('/.static/flash/swfupload.swf'),
+            flash_url: $.uri_for_static('/flash/swfupload.swf'),
             upload_url: $('#upload_link').attr('href'),	// Relative to the SWF file
             file_size_limit: "100 MB",
             file_post_name: 'file' ,
@@ -462,7 +462,7 @@ jQuery.prototype.any = function(callback) {
 setupToggleMaximized = function() {
     var $img    = $('<img id="maximize"/>');
     var max     = $("#container").hasClass('maximized-container');
-    var img_uri = $.uri_for("/.static/gfx/maximize_width_X.png");
+    var img_uri = $.uri_for_static("/gfx/maximize_width_X.png");
 
     var toggle = function() {
         if(max) {
